@@ -1,29 +1,31 @@
 #' Resample a series of GIFTIs related to a CIFTI file
 #'
-#' Performs spatial resampling of various CIFTI file components on 
-#'  the cortical surface. (The subcortical data is not resampled here.) 
-#'  GIFTI surface geometry files can additionally be included: see 
+#' Performs spatial resampling of various CIFTI file components on
+#'  the cortical surface. (The subcortical data is not resampled here.)
+#'  GIFTI surface geometry files can additionally be included: see
 #'  \code{surfL_original_fname} and \code{surfR_original_fname}.
 #'
 #' Step 1: Generate spheres in the original and target resolutions
-#'  Step 2: Use -metric-resample to resample surface/cortex files 
+#'  Step 2: Use -metric-resample to resample surface/cortex files
 #'  Step 3: Use -surface-resample to resample gifti files
-#' 
+#'
 #' @param original_res The original resolution(s) of the CIFTI cortical surface(s).
 #' @inheritParams resamp_res_Param_required
-#' @param cortexL_original_fname,cortexR_original_fname (Optional) File path of 
+#' @inheritParams resamp_method_Param
+#' @inheritParams resamp_area_Param
+#' @param cortexL_original_fname,cortexR_original_fname (Optional) File path of
 #'  GIFTI data for \[left/right\] cortex to resample.
-#' @param cortexL_target_fname,cortexR_target_fname (Optional) File path to 
+#' @param cortexL_target_fname,cortexR_target_fname (Optional) File path to
 #'  save the resampled GIFTI data for \[left/right\] cortex as.
-#'  If NULL (default) and \code{cortex[L/R]_original_fname} was provided, it 
+#'  If NULL (default) and \code{cortex[L/R]_original_fname} was provided, it
 #'  will be named by \code{\link{cifti_component_suffix}}.
-#' @param ROIcortexL_original_fname,ROIcortexR_original_fname (Optional) File 
-#'  path of GIFTI ROI corresponding to \code{cortex[L/R]_original_fname} to 
+#' @param ROIcortexL_original_fname,ROIcortexR_original_fname (Optional) File
+#'  path of GIFTI ROI corresponding to \code{cortex[L/R]_original_fname} to
 #'  resample.
-#' @param ROIcortexL_target_fname,ROIcortexR_target_fname (Optional) File path 
-#'  of to save the resampled GIFTI ROI corresponding to 
+#' @param ROIcortexL_target_fname,ROIcortexR_target_fname (Optional) File path
+#'  of to save the resampled GIFTI ROI corresponding to
 #'  \code{cortex[L/R]_target_fname} as.
-#'  If NULL (default) and \code{cortex[L/R]_original_fname} was provided, it 
+#'  If NULL (default) and \code{cortex[L/R]_original_fname} was provided, it
 #'  will be named by \code{\link{cifti_component_suffix}}.
 #' @inheritParams surfL_original_fname_Param
 #' @inheritParams surfR_original_fname_Param
@@ -35,33 +37,38 @@
 #' @return A named character vector of file paths to each resampled file
 #'
 #' @keywords internal
-#' 
+#'
 resample_cifti_components <- function(
-  original_res=NULL, resamp_res, 
-  cortexL_original_fname=NULL, cortexR_original_fname=NULL, 
-  cortexL_target_fname=NULL, cortexR_target_fname=NULL, 
-  ROIcortexL_original_fname=NULL, ROIcortexR_original_fname=NULL, 
+  original_res=NULL,
+  resamp_res=NULL, resamp_method=NULL,
+  areaL_original_fname=NULL, areaR_original_fname=NULL,
+  ROIcortex_original_fname=NULL, ROIcortex_target_fname=NULL,
+  cortexL_original_fname=NULL, cortexR_original_fname=NULL,
+  cortexL_target_fname=NULL, cortexR_target_fname=NULL,
+  ROIcortexL_original_fname=NULL, ROIcortexR_original_fname=NULL,
   ROIcortexL_target_fname=NULL, ROIcortexR_target_fname=NULL,
-  surfL_original_fname=NULL, surfR_original_fname=NULL, 
+  surfL_original_fname=NULL, surfR_original_fname=NULL,
   surfL_target_fname=NULL, surfR_target_fname=NULL,
   read_dir=NULL, write_dir=NULL) {
 
   original_fnames <- list(
-    cortexL=cortexL_original_fname, cortexR=cortexR_original_fname, 
+    areaL=areaL_original_fname, areaR=areaR_original_fname,
+    cortexL=cortexL_original_fname, cortexR=cortexR_original_fname,
     ROIcortexL=ROIcortexL_original_fname, ROIcortexR=ROIcortexR_original_fname,
     surfL=surfL_original_fname, surfR=surfR_original_fname
   )
   original_fnames <- original_fnames[!vapply(original_fnames, is.null, FALSE)]
 
   target_fnames <- list(
-    cortexL=cortexL_target_fname, cortexR=cortexR_target_fname, 
+    cortexL=cortexL_target_fname, cortexR=cortexR_target_fname,
     ROIcortexL=ROIcortexL_target_fname, ROIcortexR=ROIcortexR_target_fname,
     surfL=surfL_target_fname, surfR=surfR_target_fname
   )
   target_fnames <- target_fnames[!vapply(target_fnames, is.null, FALSE)]
 
   all_labels <- c(
-    "cortexL", "cortexR", "ROIcortexL", "ROIcortexR", "surfL", "surfR"
+    "areaL", "areaR", "cortexL", "cortexR",
+    "ROIcortexL", "ROIcortexR", "surfL", "surfR"
   )
 
   # Check original files.
@@ -98,7 +105,7 @@ resample_cifti_components <- function(
     if (sum(missing_original) > 0) {
       ciftiTools_warn(paste0(
         "Ignoring these resampling targets because",
-        " their original files were not provided:\n", 
+        " their original files were not provided:\n",
         paste(names(target_fnames)[
           !vapply(target_fnames, is.null, FALSE)][missing_original], collapse="\n"),
         "\n"
@@ -146,7 +153,7 @@ resample_cifti_components <- function(
     as.character(original_fnames), read_dir, mode=4)
   # [TO DO]: error if a file name is absolute?
 
-  # Step 2 and 3: Use -metric-resample or -surface-rsample to resample 
+  # Step 2 and 3: Use -metric-resample or -surface-rsample to resample
   #   cortex, ROI, and surface files into target resolution.
 
   resample_gifti_kwargs_common <- list(
@@ -163,30 +170,35 @@ resample_cifti_components <- function(
     is_left <- substr(lab, nchar(lab), nchar(lab)) == "L" # last char: L or R.
     resample_kwargs <- c(resample_gifti_kwargs_common, list(
       original_fname=original_fnames[[lab]], target_fname=target_fnames[[lab]],
-      hemisphere=ifelse(is_left, "left", "right"), 
+      hemisphere=ifelse(is_left, "left", "right"),
       original_res=ifelse(is_left, original_res[1], original_res[2])
     ))
-    
+
     # Resample cortical data.
     if (lab %in% c("cortexL", "cortexR")) {
       # Use ROI if provided.
       ROI_lab <- ifelse(is_left, "ROIcortexL", "ROIcortexR")
+      area_lab <- ifelse(is_left, "areaL", "areaR")
       if (ROI_lab %in% names(target_fnames)) {
         resample_kwargs <- c(
           resample_kwargs, list(
-            ROIcortex_original_fname=original_fnames[[ROI_lab]], 
+            area_original_fname=original_fnames[[area_lab]],
+            ROIcortex_original_fname=original_fnames[[ROI_lab]],
             ROIcortex_target_fname=target_fnames[[ROI_lab]]
           )
         )
       }
+      resample_kwargs <- c(
+        resample_kwargs, list(resamp_method=resamp_method)
+      )
       file_type <- ifelse(grepl(".label.gii", original_fnames[[lab]], fixed=TRUE), "label", "metric")
       do.call(resample_gifti, c(resample_kwargs, list(file_type=file_type)))
-    
+
     # Resample surfaces.
     } else if (lab %in% c("surfL", "surfR")) {
       do.call(resample_gifti, c(resample_kwargs, list(file_type="surface")))
     }
   }
-  
+
   invisible(unlist(target_fnames))
-}
\ No newline at end of file
+}
